==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl<A extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<A>{
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl(ACMEChallengeSolverHTTP01GatewayHTTPRoute instance) {
    this.withLabels(instance.getLabels()); 
    this.withServiceType(instance.getServiceType()); 
  }
  private Map<String,String> labels;
  private String serviceType;
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public Boolean hasLabels() {
    return this.labels != null;
  }
  public String getServiceType() {
    return this.serviceType;
  }
  public A withServiceType(String serviceType) {
    this.serviceType=serviceType; return (A) this;
  }
  public Boolean hasServiceType() {
    return this.serviceType != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl that = (ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl) o;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (serviceType != null ? !serviceType.equals(that.serviceType) :that.serviceType != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  serviceType,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (serviceType != null) { sb.append("serviceType:"); sb.append(serviceType); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl<A extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<A>{
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl(ACMEChallengeSolverHTTP01GatewayHTTPRoute instance) {
    if (instance != null) {
      this.withLabels(instance.getLabels());
      this.withServiceType(instance.getServiceType());
    }
  }
  private Map<String,String> labels;
  private String serviceType;
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public Boolean hasLabels() {
    return this.labels != null;
  }
  public String getServiceType() {
    return this.serviceType;
  }
  public A withServiceType(String serviceType) {
    this.serviceType=serviceType; return (A) this;
  }
  public Boolean hasServiceType() {
    return this.serviceType != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl that = (ACMEChallengeSolverHTTP01GatewayHTTPRouteFluentImpl) o;
    if (!java.util.Objects.equals(labels, that.labels)) return false;

    if (!java.util.Objects.equals(serviceType, that.serviceType)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labels,  serviceType,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (serviceType != null) { sb.append("serviceType:"); sb.append(serviceType); }
    sb.append("}");
    return sb.toString();
  }
  
}
